@@ -64,7 +64,7 @@ class BuilderConditions(object):
         pfile = path.join(Get("cl_builder_path"),
                           "var/lib/portage/preserved_libs_registry")
         content = readFile(pfile).strip()
-        if not content or content == '{}':
+        if not content or content[1:-1].strip() == '':
             return False
         else:
             return True
@@ -317,7 +317,7 @@ class ClBuilderUpdateAction(Action):
                                 '"@preserved-rebuild")',
                       'condition': lambda Get: (
                           BuilderConditions.was_installed(
-                              '.*', EmergeMark.PreservedLibs) or
+                              '.*', EmergeMark.PreservedLibs)(Get) or
                           BuilderConditions.force_preserved(Get)),
                       'decoration': 'Builder.update_task("%s")' %
                                     EmergeMark.PreservedLibs
