@@ -69,6 +69,7 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     env.VariableClPkgdir(),
                     env.VariableClDistdir(),
                     env.VariableClEmergeConfig(systemRoot=self.systemRoot),
+                    env.VariableClEmergeInfo(systemRoot=self.systemRoot),
                     env.VariableClFeatures(),
                     env.VariableClEmergeDefaultOpts(),
                     env.VariableClEnvLocation(),
@@ -162,6 +163,7 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
             self.Get('update.cl_update_binhost_recheck_set')
         dvbl['cl_update_binhost_stable_opt_set'] = \
             self.Get('cl_builder_binhost_stable_set')
+        dvbl['cl_update_binhost_stable_set'] = "off"
         if self.Get('cl_action') not in (
                 Actions.Update, Actions.ChangeProfile) or \
                 not self.GetBool('cl_builder_binhost_scan_set'):
